@@ -1,10 +1,20 @@
 .VERSION_HELP <- "see https://bioconductor.org/install"
 
 .VERSION_UNKNOWN <-
-    "Bioconductor version cannot be determined; no internet connection?"
+    "Bioconductor version cannot be determined; no internet connection?
+    See #troubleshooting section in vignette"
 
 .VERSION_MAP_UNABLE_TO_VALIDATE <-
-    "Bioconductor version cannot be validated; no internet connection?"
+    "Bioconductor version cannot be validated; no internet connection?
+    See #troubleshooting section in vignette"
+
+.VERSION_MAP_MISCONFIGURATION <-
+    "Bioconductor version map cannot be validated; is it misconfigured?
+    See #troubleshooting section in vignette"
+
+.VERSION_TYPE_MISSPECIFICATION <-
+    "Bioconductor version cannot be validated; is type input misspecified?
+    See #troubleshooting section in vignette"
 
 .NO_ONLINE_VERSION_DIAGNOSIS <-
     "Bioconductor online version validation disabled;
@@ -13,21 +23,22 @@
 .LEGACY_INSTALL_CMD <-
     "source(\"https://bioconductor.org/biocLite.R\")"
 
+.VERSION_TAGS <-
+    c("out-of-date", "release", "devel", "future")
+
 .VERSION_MAP_SENTINEL <- data.frame(
-    Bioc = package_version(list()),
-    R = package_version(list()),
+    Bioc = package_version(character()),
+    R = package_version(character()),
     BiocStatus = factor(
         factor(),
-        levels = c("out-of-date", "release", "devel", "future")
-    ),
-    RSPM = character(),
-    MRAN = character()
+        levels = .VERSION_TAGS
+    )
 )
 
 .version_sentinel <-
     function(msg)
 {
-    version <- package_version(list())
+    version <- package_version(NA_character_, strict = FALSE)
     structure(
         unclass(version),
         msg = msg,
@@ -120,16 +131,15 @@ format.version_sentinel <-
     if (toggle_warning)
         .VERSION_MAP$WARN_NO_ONLINE_CONFIG <- FALSE
 
-    if (inherits(txt, "error"))
+    if (!length(txt) || inherits(txt, "error"))
         return(.VERSION_MAP_SENTINEL)
 
     bioc_r_map <- .version_map_config_element(txt, "r_ver_for_bioc_ver")
+    if (!length(bioc_r_map))
+        return(.VERSION_MAP_SENTINEL)
     bioc <- package_version(names(bioc_r_map))
     r <- package_version(unname(bioc_r_map))
 
-    bioc_rspm_map <- .version_map_config_element(txt, "rspm_ver_for_bioc_ver")
-    bioc_mran_map <- .version_map_config_element(txt, "mran_ver_for_bioc_ver")
-
     pattern <- "^release_version: \"(.*)\""
     release <- package_version(
         sub(pattern, "\\1", grep(pattern, txt, value=TRUE))
@@ -159,33 +169,27 @@ format.version_sentinel <-
         Bioc = bioc, R = r,
         BiocStatus = factor(
             status,
-            levels = c("out-of-date", "release", "devel", "future")
-        ),
-        RSPM = unname(bioc_rspm_map[as.character(bioc)]),
-        MRAN = unname(bioc_mran_map[as.character(bioc)])
-   ))
+            levels = .VERSION_TAGS
+        )  
+    ))
 }
 
 .version_map_get_offline <-
     function()
 {
-    bioc <- tryCatch({
-        packageVersion("BiocVersion")[, 1:2]
-    }, error = identity)
-    if (inherits(bioc, "error"))
+    bioc <- .version_BiocVersion()
+    if (is.na(bioc))
         return(.VERSION_MAP_SENTINEL)
 
-    r <- package_version(R.Version())[,1:2]
+    r <- .version_R_version()[,1:2]
 
-    status <- c("out-of-date", "release", "devel", "future")
+    status <- .VERSION_TAGS
     rbind(.VERSION_MAP_SENTINEL, data.frame(
         Bioc = bioc, R = r,
         BiocStatus = factor(
             NA,
             levels = status
-        ),
-        RSPM = NA_character_,
-        MRAN = NA_character_
+        )
     ))
 }
 
@@ -222,9 +226,21 @@ format.version_sentinel <-
     map[idx, field]
 }
 
-.get_R_version <- function()
+.version_R_version <- function()
     getRversion()
 
+.version_BiocVersion_installed <- function()
+    nzchar(system.file(package = "BiocVersion"))
+
+.version_BiocVersion <-
+    function()
+{
+    if (.version_BiocVersion_installed())
+        packageVersion("BiocVersion")[, 1:2]
+    else
+        .version_sentinel("BiocVersion is not installed")
+}
+
 .version_string <-
     function(bioc_version = version())
 {
@@ -240,7 +256,8 @@ format.version_sentinel <-
 ## the version is invalid. It does NOT call message / warning / etc
 ## directly.
 .version_validity <-
-    function(version, map = .version_map(), r_version = .get_R_version())
+    function(version, map = .version_map(), r_version = .version_R_version(),
+             check_future = FALSE)
 {
     if (identical(version, "devel"))
         version <- .version_bioc("devel")
@@ -257,27 +274,32 @@ format.version_sentinel <-
     if (identical(map, .VERSION_MAP_SENTINEL))
         return(.VERSION_MAP_UNABLE_TO_VALIDATE)
 
+    if (!all(.VERSION_TAGS %in% map$BiocStatus))
+        return(.VERSION_MAP_MISCONFIGURATION)
+
     if (!version %in% map$Bioc)
         return(sprintf(
             "unknown Bioconductor version '%s'; %s", version, .VERSION_HELP
         ))
 
-    required <- map$R[map$Bioc == version & map$BiocStatus != "future"]
+    required <- map$R[map$Bioc == version & !map$BiocStatus %in% "future"]
     r_version <- r_version[, 1:2]
     if (!r_version %in% required) {
         rec <- map[map$R == r_version, , drop = FALSE]
         one_up <- required
         one_up[, 2] <- as.integer(required[, 2]) + 1L
-        if (r_version == one_up && "future" %in% rec$BiocStatus)
-            return(sprintf(
-                "Bioconductor does not yet build and check packages for R
-                 version %s; %s",
-                r_version, .VERSION_HELP
-            ))
-        else {
+        if (r_version == one_up && "future" %in% rec$BiocStatus) {
+            if (check_future) {
+                return(sprintf(
+                    "Bioconductor does not yet build and check packages for R
+                     version %s, using unsupported Bioconductor version %s; %s",
+                    r_version, version, .VERSION_HELP
+                ))
+            }
+        } else {
             rec_fun <- ifelse("devel" %in% rec$BiocStatus, head, tail)
             rec_msg <- sprintf(
-                "use `BiocManager::install(version = '%s')` with R version %s",
+                "use `version = '%s'` with R version %s",
                 rec_fun(rec$Bioc, 1), r_version
             )
 
@@ -291,25 +313,6 @@ format.version_sentinel <-
     TRUE
 }
 
-.version_is_not_future <-
-    function(version)
-{
-    map <- .version_map()
-    if (identical(map, .VERSION_MAP_SENTINEL))
-        return(.VERSION_MAP_UNABLE_TO_VALIDATE)
-
-    r_version <- getRversion()[, 1:2]
-    status <- map$BiocStatus[map$Bioc == version & map$R == r_version]
-    if (identical(status, "future"))
-        return(sprintf(
-            "Bioconductor does not yet build and check packages for R version
-             %s; %s",
-            r_version, .VERSION_HELP
-        ))
-
-    TRUE
-}
-
 .version_validate <-
     function(version)
 {
@@ -360,6 +363,9 @@ format.version_sentinel <-
     if (identical(map, .VERSION_MAP_SENTINEL))
         return(.version_sentinel(.VERSION_MAP_UNABLE_TO_VALIDATE))
 
+    if (!all(.VERSION_TAGS %in% map$BiocStatus))
+        return(.version_sentinel(.VERSION_MAP_MISCONFIGURATION))
+
     map <- map[map$R == getRversion()[, 1:2],]
     if ("release" %in% map$BiocStatus)
         idx <- map$BiocStatus == "release"
@@ -380,8 +386,14 @@ format.version_sentinel <-
     if (identical(map, .VERSION_MAP_SENTINEL))
         return(.VERSION_MAP_UNABLE_TO_VALIDATE)
 
+    if (!all(.VERSION_TAGS %in% map$BiocStatus))
+        return(.VERSION_MAP_MISCONFIGURATION)
+
+    if (!type %in% .VERSION_TAGS)
+        return(.VERSION_TYPE_MISSPECIFICATION)
+
     version <- map$Bioc[map$BiocStatus == type]
-    if (is.na(version))
+    if (!length(version) || is.na(version))
         version <- .VERSION_UNKNOWN
     version
 }
@@ -393,17 +405,16 @@ format.version_sentinel <-
     if (identical(map, .VERSION_MAP_SENTINEL))
         return(.VERSION_MAP_UNABLE_TO_VALIDATE)
 
-    map$R[map$BiocStatus == type]
-}
+    if (!all(.VERSION_TAGS %in% map$BiocStatus))
+        return(.VERSION_MAP_MISCONFIGURATION)
 
-.local_version <-
-    function()
-{
-    tryCatch({
-        packageVersion("BiocVersion")[, 1:2]
-    }, error = function(e) {
-        .version_sentinel("package 'BiocVersion' not installed")
-    })
+    if (!type %in% .VERSION_TAGS)
+        return(.VERSION_TYPE_MISSPECIFICATION)
+
+    version <- map$R[map$BiocStatus == type]
+    if (!length(version) || is.na(version))
+        version <- .VERSION_UNKNOWN
+    version
 }
 
 #' Version of Bioconductor currently in use.
@@ -428,11 +439,11 @@ format.version_sentinel <-
 version <-
     function()
 {
-    tryCatch({
-        packageVersion("BiocVersion")[, 1:2]
-    }, error = function(e) {
-        .version_choose_best()
-    })
+    bioc <- .version_BiocVersion()
+    if (is.na(bioc))
+        bioc <- .version_choose_best()
+
+    bioc
 }
 
 .package_version <-
@@ -456,5 +467,5 @@ version <-
 print.version_sentinel <-
     function(x, ...)
 {
-    cat(format(x), "\n")
+    cat(format(x), "\n", sep = "")
 }
